const canvas = document.getElementById('network-canvas');
const ctx = canvas.getContext('2d');

const nodes = [
  { id: 'New York', x: 100, y: 50 },
  { id: 'Los Angeles', x: 250, y: 100 },
  { id: 'Chicago', x: 400, y: 50 },
  { id: 'Houston', x: 250, y: 250 },
  { id: 'Phoenix', x: 600, y: 150 },
  { id: 'Philadelphia', x: 750, y: 200 },
  { id: 'San Antonio', x: 600, y: 250 },
  { id: 'San Diego', x: 450, y: 300 },
  { id: 'Dallas', x: 100, y: 250 },
  { id: 'San Jose', x: 100, y: 100 },
];

const links = [
  { source: 'New York', target: 'Los Angeles' },
  { source: 'New York', target: 'Chicago' },
  { source: 'New York', target: 'Houston' },
  { source: 'Los Angeles', target: 'Chicago' },
  { source: 'Los Angeles', target: 'Phoenix' },
  { source: 'Chicago', target: 'Houston' },
  { source: 'Chicago', target: 'Philadelphia' },
  { source: 'Houston', target: 'San Antonio' },
  { source: 'Houston', target: 'San Diego' },
  { source: 'Phoenix', target: 'Philadelphia' },
  { source: 'Phoenix', target: 'San Antonio' },
  { source: 'Philadelphia', target: 'San Jose' },
  { source: 'Philadelphia', target: 'Dallas' },
  { source: 'San Antonio', target: 'San Jose' },
  { source: 'San Antonio', target: 'Dallas' },
  { source: 'San Diego', target: 'Dallas' },
];

function drawNodes() {
  nodes.forEach((node) => {
    const sides = 6; // Number of sides for polygon
    const radius = 20;

    ctx.beginPath();
    ctx.moveTo(
      node.x + radius * Math.cos(0),
      node.y + radius * Math.sin(0),
    );

    for (let i = 1; i <= sides; i++) {
      ctx.lineTo(
        node.x +
          radius * Math.cos((i * 2 * Math.PI) / sides),
        node.y +
          radius * Math.sin((i * 2 * Math.PI) / sides),
      );
    }

    ctx.closePath();
    ctx.fillStyle = '#FF6347'; // Tomato
    ctx.fill();

    // Node label
    ctx.fillStyle = 'black';
    ctx.font = '14px Arial';
    ctx.textAlign = 'center';
    ctx.textBaseline = 'middle';
    ctx.fillText(node.id, node.x, node.y);
  });
}

function drawLinks() {
  links.forEach((link) => {
    const sourceNode = nodes.find(
      (node) => node.id === link.source,
    );
    const targetNode = nodes.find(
      (node) => node.id === link.target,
    );

    ctx.beginPath();
    ctx.moveTo(sourceNode.x, sourceNode.y);
    ctx.lineTo(targetNode.x, targetNode.y);
    ctx.strokeStyle = '#6B8E23'; // OliveDrab
    ctx.lineWidth = 2;
    ctx.stroke();
  });
}

function drawGraph() {
  drawLinks();
  drawNodes();
}

function adjustCanvasSize() {
  let maxX = 0;
  let maxY = 0;

  nodes.forEach((node) => {
    if (node.x > maxX) maxX = node.x;
    if (node.y > maxY) maxY = node.y;
  });

  canvas.width = maxX + 50;
  canvas.height = maxY + 50;
}

adjustCanvasSize();
drawGraph();
